@@ -262,6 +262,7 @@ class PrivateKey(BaseKey):
         message=None,
         unspents=None,
         message_is_hex=False,
+        replace_by_fee=False
     ):  # pragma: no cover
         """Creates a signed P2PKH transaction.
 
@@ -292,6 +293,8 @@ class PrivateKey(BaseKey):
         :param unspents: The UTXOs to use as the inputs. By default Bit will
                          communicate with the blockchain itself.
         :type unspents: ``list`` of :class:`~bit.network.meta.Unspent`
+        :param replace_by_fee: Whether to opt-in for replace-by-fee (BIP 125).
+        :type replace_by_fee: ``bool``
         :returns: The signed transaction as hex.
         :rtype: ``str``
         """
@@ -313,6 +316,7 @@ class PrivateKey(BaseKey):
             absolute_fee=absolute_fee,
             version=self.version,
             message_is_hex=message_is_hex,
+            replace_by_fee=replace_by_fee
         )
 
         return create_new_transaction(self, unspents, outputs)
@@ -327,6 +331,7 @@ class PrivateKey(BaseKey):
         message=None,
         unspents=None,
         message_is_hex=False,
+        replace_by_fee=False
     ):  # pragma: no cover
         """Creates a signed P2PKH transaction and attempts to broadcast it on
         the blockchain. This accepts the same arguments as
@@ -359,6 +364,8 @@ class PrivateKey(BaseKey):
         :param unspents: The UTXOs to use as the inputs. By default Bit will
                          communicate with the blockchain itself.
         :type unspents: ``list`` of :class:`~bit.network.meta.Unspent`
+        :param replace_by_fee: Whether to opt-in for replace-by-fee (BIP 125).
+        :type replace_by_fee: ``bool``
         :returns: The transaction ID.
         :rtype: ``str``
         """
@@ -372,6 +379,7 @@ class PrivateKey(BaseKey):
             message=message,
             unspents=unspents,
             message_is_hex=message_is_hex,
+            replace_by_fee=replace_by_fee
         )
 
         NetworkAPI.broadcast_tx(tx_hex)
@@ -391,6 +399,7 @@ class PrivateKey(BaseKey):
         message=None,
         unspents=None,
         message_is_hex=False,
+        replace_by_fee=False
     ):  # pragma: no cover
         """Prepares a P2PKH transaction for offline signing.
 
@@ -426,6 +435,8 @@ class PrivateKey(BaseKey):
         :param unspents: The UTXOs to use as the inputs. By default Bit will
                          communicate with the blockchain itself.
         :type unspents: ``list`` of :class:`~bit.network.meta.Unspent`
+        :param replace_by_fee: Whether to opt-in for replace-by-fee (BIP 125).
+        :type replace_by_fee: ``bool``
         :returns: JSON storing data required to create an offline transaction.
         :rtype: ``str``
         """
@@ -439,6 +450,7 @@ class PrivateKey(BaseKey):
             absolute_fee=absolute_fee,
             version='main',
             message_is_hex=message_is_hex,
+            replace_by_fee=replace_by_fee
         )
 
         data = {'unspents': [unspent.to_dict() for unspent in unspents], 'outputs': outputs}
@@ -649,6 +661,7 @@ class PrivateKeyTestnet(BaseKey):
         message=None,
         unspents=None,
         message_is_hex=False,
+        replace_by_fee=False
     ):  # pragma: no cover
         """Creates a signed P2PKH transaction.
 
@@ -679,6 +692,8 @@ class PrivateKeyTestnet(BaseKey):
         :param unspents: The UTXOs to use as the inputs. By default Bit will
                          communicate with the testnet blockchain itself.
         :type unspents: ``list`` of :class:`~bit.network.meta.Unspent`
+        :param replace_by_fee: Whether to opt-in for replace-by-fee (BIP 125).
+        :type replace_by_fee: ``bool``
         :returns: The signed transaction as hex.
         :rtype: ``str``
         """
@@ -700,6 +715,7 @@ class PrivateKeyTestnet(BaseKey):
             absolute_fee=absolute_fee,
             version=self.version,
             message_is_hex=message_is_hex,
+            replace_by_fee=replace_by_fee
         )
 
         return create_new_transaction(self, unspents, outputs)
@@ -714,6 +730,7 @@ class PrivateKeyTestnet(BaseKey):
         message=None,
         unspents=None,
         message_is_hex=False,
+        replace_by_fee=False
     ):  # pragma: no cover
         """Creates a signed P2PKH transaction and attempts to broadcast it on
         the testnet blockchain. This accepts the same arguments as
@@ -746,6 +763,8 @@ class PrivateKeyTestnet(BaseKey):
         :param unspents: The UTXOs to use as the inputs. By default Bit will
                          communicate with the testnet blockchain itself.
         :type unspents: ``list`` of :class:`~bit.network.meta.Unspent`
+        :param replace_by_fee: Whether to opt-in for replace-by-fee (BIP 125).
+        :type replace_by_fee: ``bool``
         :returns: The transaction ID.
         :rtype: ``str``
         """
@@ -759,6 +778,7 @@ class PrivateKeyTestnet(BaseKey):
             message=message,
             unspents=unspents,
             message_is_hex=message_is_hex,
+            replace_by_fee=replace_by_fee
         )
 
         NetworkAPI.broadcast_tx_testnet(tx_hex)
@@ -778,6 +798,7 @@ class PrivateKeyTestnet(BaseKey):
         message=None,
         unspents=None,
         message_is_hex=False,
+        replace_by_fee=False
     ):  # pragma: no cover
         """Prepares a P2PKH transaction for offline signing.
 
@@ -813,6 +834,8 @@ class PrivateKeyTestnet(BaseKey):
         :param unspents: The UTXOs to use as the inputs. By default Bit will
                          communicate with the blockchain itself.
         :type unspents: ``list`` of :class:`~bit.network.meta.Unspent`
+        :param replace_by_fee: Whether to opt-in for replace-by-fee (BIP 125).
+        :type replace_by_fee: ``bool``
         :returns: JSON storing data required to create an offline transaction.
         :rtype: ``str``
         """
@@ -826,6 +849,7 @@ class PrivateKeyTestnet(BaseKey):
             absolute_fee=absolute_fee,
             version='test',
             message_is_hex=message_is_hex,
+            replace_by_fee=replace_by_fee
         )
 
         data = {'unspents': [unspent.to_dict() for unspent in unspents], 'outputs': outputs}
@@ -1076,6 +1100,7 @@ class MultiSig:
         message=None,
         unspents=None,
         message_is_hex=False,
+        replace_by_fee=False
     ):  # pragma: no cover
         """Creates a signed P2SH transaction.
 
@@ -1106,6 +1131,8 @@ class MultiSig:
         :param unspents: The UTXOs to use as the inputs. By default Bit will
                          communicate with the testnet blockchain itself.
         :type unspents: ``list`` of :class:`~bit.network.meta.Unspent`
+        :param replace_by_fee: Whether to opt-in for replace-by-fee (BIP 125).
+        :type replace_by_fee: ``bool``
         :returns: The signed transaction as hex.
         :rtype: ``str``
         """
@@ -1127,6 +1154,7 @@ class MultiSig:
             absolute_fee=absolute_fee,
             version=self.version,
             message_is_hex=message_is_hex,
+            replace_by_fee=replace_by_fee
         )
 
         return create_new_transaction(self, unspents, outputs)
@@ -1144,6 +1172,7 @@ class MultiSig:
         message=None,
         unspents=None,
         message_is_hex=False,
+        replace_by_fee=False
     ):  # pragma: no cover
         """Prepares a P2SH transaction for offline signing.
 
@@ -1179,6 +1208,8 @@ class MultiSig:
         :param unspents: The UTXOs to use as the inputs. By default Bit will
                          communicate with the blockchain itself.
         :type unspents: ``list`` of :class:`~bit.network.meta.Unspent`
+        :param replace_by_fee: Whether to opt-in for replace-by-fee (BIP 125).
+        :type replace_by_fee: ``bool``
         :returns: JSON storing data required to create an offline transaction.
         :rtype: ``str``
         """
@@ -1192,6 +1223,7 @@ class MultiSig:
             absolute_fee=absolute_fee,
             version='main',
             message_is_hex=message_is_hex,
+            replace_by_fee=replace_by_fee
         )
 
         data = {'unspents': [unspent.to_dict() for unspent in unspents], 'outputs': outputs}
@@ -1397,6 +1429,7 @@ class MultiSigTestnet:
         message=None,
         unspents=None,
         message_is_hex=False,
+        replace_by_fee=False
     ):  # pragma: no cover
         """Creates a signed P2SH transaction.
 
@@ -1427,6 +1460,8 @@ class MultiSigTestnet:
         :param unspents: The UTXOs to use as the inputs. By default Bit will
                          communicate with the testnet blockchain itself.
         :type unspents: ``list`` of :class:`~bit.network.meta.Unspent`
+        :param replace_by_fee: Whether to opt-in for replace-by-fee (BIP 125).
+        :type replace_by_fee: ``bool``
         :returns: The signed transaction as hex.
         :rtype: ``str``
         """
@@ -1448,6 +1483,7 @@ class MultiSigTestnet:
             absolute_fee=absolute_fee,
             version=self.version,
             message_is_hex=message_is_hex,
+            replace_by_fee=replace_by_fee
         )
 
         return create_new_transaction(self, unspents, outputs)
@@ -1465,6 +1501,7 @@ class MultiSigTestnet:
         message=None,
         unspents=None,
         message_is_hex=False,
+        replace_by_fee=False
     ):  # pragma: no cover
         """Prepares a P2SH transaction for offline signing.
 
@@ -1500,6 +1537,8 @@ class MultiSigTestnet:
         :param unspents: The UTXOs to use as the inputs. By default Bit will
                          communicate with the blockchain itself.
         :type unspents: ``list`` of :class:`~bit.network.meta.Unspent`
+        :param replace_by_fee: Whether to opt-in for replace-by-fee (BIP 125).
+        :type replace_by_fee: ``bool``
         :returns: JSON storing data required to create an offline transaction.
         :rtype: ``str``
         """
@@ -1513,6 +1552,7 @@ class MultiSigTestnet:
             absolute_fee=absolute_fee,
             version='test',
             message_is_hex=message_is_hex,
+            replace_by_fee=replace_by_fee
         )
 
         data = {'unspents': [unspent.to_dict() for unspent in unspents], 'outputs': outputs}
